@@ -1,7 +1,7 @@
 package Getopt::Long::Negate::EN;
 
-our $DATE = '2015-03-19'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2016-01-03'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,13 +12,25 @@ our @EXPORT_OK = qw(negations_for_option);
 
 sub negations_for_option {
     my $word = shift;
+
     if    ($word =~ /\Awith([_-].+)/   ) { return ("without$1") }
     elsif ($word =~ /\Awithout([_-].+)/) { return ("with$1")    }
+
     elsif ($word =~ /\Ais([_-].+)/     ) { return ("isnt$1")    }
     elsif ($word =~ /\Aisnt([_-].+)/   ) { return ("is$1")      }
     elsif ($word =~ /\Aare([_-].+)/    ) { return ("arent$1")   }
     elsif ($word =~ /\Aarent([_-].+)/  ) { return ("are$1")     }
+
+    elsif ($word =~ /\Ahas([_-].+)/    ) { return ("hasnt$1")   }
+    elsif ($word =~ /\Ahave([_-].+)/   ) { return ("havent$1")  }
+    elsif ($word =~ /\Ahasnt([_-].+)/  ) { return ("has$1")     }
+    elsif ($word =~ /\Ahavent([_-].+)/ ) { return ("have$1")    }
+
+    elsif ($word =~ /\Acan([_-].+)/    ) { return ("cant$1")    }
+    elsif ($word =~ /\Acant([_-].+)/   ) { return ("can$1")     }
+
     elsif ($word =~ /\Ano[_-](.+)/     ) { return ($1)          }
+
     else {
         # default from Getopt::Long
         return ("no-$word", "no$word");
@@ -40,7 +52,7 @@ Getopt::Long::Negate::EN - Better negation of boolean option names
 
 =head1 VERSION
 
-This document describes version 0.01 of Getopt::Long::Negate::EN (from Perl distribution Getopt-Long-Negate-EN), released on 2015-03-19.
+This document describes version 0.02 of Getopt::Long::Negate::EN (from Perl distribution Getopt-Long-Negate-EN), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -96,7 +108,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
